@@ -7,7 +7,7 @@ use PerlIO::encoding;
 $Data::Dumper::Sortkeys = 1;
 use FASTX::Seq;
 use File::Basename;
-$FASTX::Reader::VERSION = '1.12.0';
+$FASTX::Reader::VERSION = '1.12.1';
 require Exporter;
 our @ISA = qw(Exporter);
 
@@ -483,7 +483,7 @@ FASTX::Reader - A simple module to parse FASTA and FASTQ files, supporting compr
 
 =head1 VERSION
 
-version 1.12.0
+version 1.12.1
 
 =head1 SYNOPSIS
 
@@ -611,18 +611,10 @@ This subroutine returns 'fasta', 'fastq' or <undef> for a given filepath (this i
 
 =head1 ACKNOWLEDGEMENTS
 
-=over 4
+This module is a has been inspired by the I<readfq()> subroutine originally written by B<Heng Li>.
+Initially I updated the subroutine to retain comments, and then it gradually became a module.
 
-=item B<Heng Li's readfq()>
-
-This module is a has been inspired by the I<readfq()> subroutine originally written by Heng Li, that I updated
-to retain I<sequence comments>. See: L<readfq repository|https://github.com/telatin/readfq>
-
-=item B<Fabrizio Levorin>
-
-has contributed to the prototyping of this module
-
-=back
+B<Fabrizio Levorin> has contributed to the prototyping of this module, many thanks to him.
 
 =head1 SEE ALSO
 
@@ -630,21 +622,20 @@ has contributed to the prototyping of this module
 
 =item L<BioX::Seq::Stream>
 
-The module I would have used if it was available when I started working on this. The .gz reader implementation comes from this module.
+The module I would have used if it was available when I started working on this. 
+The .gz reader implementation comes from this module. I think it's useful and well written too.
 
 =back
 
-=head1 AUTHOR
+=head1 CITING
 
-Andrea Telatin <andrea@telatin.com>
+If you use this module in your research, please cite:
 
-=head1 COPYRIGHT AND LICENSE
+=over 4
 
-This software is Copyright (c) 2019 by Andrea Telatin.
+=item Telatin A, Fariselli P, Birolo G. I<SeqFu: A Suite of Utilities for the Robust and Reproducible Manipulation of Sequence Files>. Bioengineering 2021, 8, 59. L<https://doi.org/10.3390/bioengineering8050059>
 
-This is free software, licensed under:
-
-  The MIT (X11) License
+=back
 
 =head1 AUTHOR
 
